@@ -1,6 +1,6 @@
 ;;; tramp-cmds.el --- Interactive commands for Tramp  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2007-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
 ;; Author: Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, processes
@@ -122,7 +122,7 @@ When called interactively, a Tramp connection has to be selected."
 
     ;; Cancel timer.
     (dolist (timer timer-list)
-      (when (and (eq (timer--function timer) 'tramp-timeout-session)
+      (when (and (eq (timer--function timer) #'tramp-timeout-session)
 		 (tramp-file-name-equal-p vec (car (timer--args timer))))
 	(cancel-timer timer)))
 
@@ -611,7 +611,9 @@ If the buffer runs `dired', the buffer is reverted."
   (interactive)
   (cond
    ((buffer-file-name)
-    (find-alternate-file (tramp-file-name-with-sudo (buffer-file-name))))
+    (let ((pos (point)))
+      (find-alternate-file (tramp-file-name-with-sudo (buffer-file-name)))
+      (goto-char pos)))
    ((tramp-dired-buffer-p)
     (dired-unadvertise (expand-file-name default-directory))
     (setq default-directory (tramp-file-name-with-sudo default-directory)
